==> kylin-super-sdk-1.0.11-sources.jar: com/bxm/kylin/_super/sdk/DefaultKylinApiClientImpl.java <==
package com.bxm.kylin._super.sdk;

import com.alibaba.fastjson.JSONObject;
import com.bxm.kylin._super.sdk.modal.*;
import com.bxm.warcar.cache.DataExtractor;
import com.bxm.warcar.cache.Fetcher;
import com.bxm.warcar.utils.KeyBuilder;
import com.bxm.warcar.utils.TypeHelper;
import com.bxm.warcar.utils.http.pool.RestTemplatePool;
import com.bxm.warcar.utils.http.properties.HttpProperties;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.util.UriComponents;
import org.springframework.web.util.UriComponentsBuilder;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;

/**
 * @author allen
 * @date 2021-06-08
 * @since 1.0
 */
@Slf4j
public class DefaultKylinApiClientImpl implements KylinApiClient {

    private final Fetcher fetcher;
    private final RestTemplatePool rest;
    private final KylinProperties kylinProperties;

    public DefaultKylinApiClientImpl(Fetcher fetcher, KylinProperties kylinProperties) {
        this.fetcher = fetcher;
        this.rest = new RestTemplatePool(new HttpProperties());
        this.kylinProperties = kylinProperties;
    }

    @Override
    public List<Domain> getAvailableDomains(String groupId, String ua, String ip) {
        return this.getAvailableDomains(groupId, ua, ip, "");
    }

    @Override
    public List<Domain> getAvailableDomains(String groupId, String ua, String ip, String path) {
        Map<String, Object> params = Maps.newHashMap();
        params.put("groupId", groupId);
        params.put("ua", ua);
        params.put("ip", ip);
        params.put("path", path);
        try {
            String url = kylinProperties.getRedirectHost() + "/domains?groupId={groupId}&ua={ua}&ip={ip}&path={path}";
            HttpEntity<String> exchange = this.post(url, String.class, params);
            if (!exchange.hasBody()) {
                return null;
            }
            return JSONObject.parseArray(exchange.getBody(), Domain.class);
        } catch (Exception e) {
            log.error("post: ", e);
            return null;
        }
    }

    @Override
    public List<DomainGroup> getDomainGroups() {
        return fetcher.fetchList(() -> KeyBuilder.build("tmp", "kylin", "domainGroups"), new DataExtractor<List<DomainGroup>>() {
            @Override
            public List<DomainGroup> extract() {
                Map<String, Object> params = Maps.newHashMap();
                params.put("size", 100);
                params.put("current", 1);
                try {
                    String url = kylinProperties.getApiHost() + "/domain-group/page-query?size={size}&current={current}";
                    HttpEntity<DomainGroupPage> entity = get(url, DomainGroupPage.class, params);
                    DomainGroupPage body = entity.getBody();
                    if (Objects.isNull(body)) {
                        return null;
                    }
                    return body.getRecords();
                } catch (Exception e) {
                    log.error("exchange: ", e);
                    return null;
                }
            }
        }, DomainGroup.class, 5 * 60);
    }

    @Override
    public CheckPlan createCheckPlan(Long envId, Long groupId, Long domainId, String sourceUrl) {
        return createCheckPlan(envId, groupId, domainId, sourceUrl, StringUtils.EMPTY);
    }

    @Override
    public CheckPlan createCheckPlan(Long envId, Long groupId, Long domainId, String sourceUrl, String remark) {
        UriComponents build = UriComponentsBuilder.fromUriString(sourceUrl).build();

        String path = build.getPath();

        if (Objects.nonNull(groupId)) {
            CheckPlan exists = getCheckPlanOnCreateJustNow(envId, groupId, domainId, path);
            if (Objects.nonNull(exists)) {
                return exists;
            }
        }

        CheckPlan checkPlan = CheckPlan.builder()
                .environmentId(envId)
                .domainId(domainId)
                .checkPath(path)
                .expectStatusCode(200)
                .cronExpression("0 0/1 * * * ?")
                .status(1)
                .webhook(kylinProperties.getWebhook())
                .remark(remark)
                .build();

        try {
            String url = kylinProperties.getApiHost() + "/check-plan/put";
            HttpEntity<CheckPlan> exchange = this.put(url, CheckPlan.class, checkPlan, Maps.newHashMap());
            CheckPlan res = exchange.getBody();
            if (Objects.nonNull(res)) {
                res.setLastCheckResult(CheckPlan.ENABLE);
            }
            return res;
        } catch (Exception e) {
            log.error("exchange: ", e);
            return null;
        }
    }

    @Override
    public void deleteCheckPlan(Long checkPlanId) {
        try {
            String url = kylinProperties.getApiHost() + "/check-plan/delete/" + checkPlanId;
            this.delete(url, String.class, Maps.newHashMap());
        } catch (Exception e) {
            log.info("{} delete checkPlan occur error: {}", checkPlanId, e.getMessage());
        }
    }

    /**
     * 获取指定条件下刚刚创建，还没有检测过的计划。
     *
     * @param envId EnvId
     * @param groupId Group id
     * @param domainId Domain id
     * @param path Path
     * @return 返回 null 则表示没有或有已检测过的计划
     */
    private CheckPlan getCheckPlanOnCreateJustNow(Long envId, Long groupId, Long domainId, String path) {
        Map<String, Object> params = Maps.newHashMap();
        params.put("size", 100);
        params.put("current", 1);
        params.put("environmentId", envId);
        params.put("groupId", groupId);
        params.put("domainId", domainId);
        params.put("status", "1");
        try {
            String url = kylinProperties.getApiHost() + "/check-plan/page-query?size={size}&current={current}&environmentId={environmentId}&groupId={groupId}&domainId={domainId}&status={status}";
            HttpEntity<CheckPlanPage> entity = get(url, CheckPlanPage.class, params);
            CheckPlanPage body = entity.getBody();
            if (Objects.isNull(body)) {
                return null;
            }
            List<CheckPlan> records = body.getRecords();
            Optional<CheckPlan> exists = records.stream().filter((e) -> e.isNewPlan() && StringUtils.equalsIgnoreCase(e.getCheckPath(), path)).findFirst();
            return exists.orElse(null);
        } catch (Exception e) {
            log.error("exchange: ", e);
            return null;
        }
    }

    private <T> HttpEntity<T> get(String url, Class<T> responseType, Map<String, Object> params) {
        HttpEntity<String> httpEntity = new HttpEntity<>(null, createHeaders());
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.GET, httpEntity, responseType, params);
    }

    private <T> HttpEntity<T> post(String url, Class<T> responseType, Map<String, Object> params) {
        HttpEntity<String> httpEntity = new HttpEntity<>(null, createHeaders());
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.POST, httpEntity, responseType, params);
    }

    private <T> HttpEntity<T> put(String url, Class<T> responseType, Object body, Map<String, Object> params) {
        HttpHeaders httpHeaders = createHeaders();
        httpHeaders.add("Content-Type", "application/json");
        HttpEntity<Object> httpEntity = new HttpEntity<>(body, httpHeaders);
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.PUT, httpEntity, responseType, params);
    }

    private <T> HttpEntity<T> delete(String url, Class<T> responseType, Map<String, Object> params) {
        HttpEntity<String> httpEntity = new HttpEntity<>(null, createHeaders());
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.DELETE, httpEntity, responseType, params);
    }

    private HttpHeaders createHeaders() {
        HttpHeaders headers = new HttpHeaders();
        headers.add("x-kylin-super-sdk", TypeHelper.castToString(System.currentTimeMillis()));
        return headers;
    }
}

==> kylin-super-sdk-1.0.19-sources.jar: com/bxm/kylin/_super/sdk/DefaultKylinApiClientImpl.java <==
package com.bxm.kylin._super.sdk;

import com.alibaba.fastjson.JSONObject;
import com.bxm.kylin._super.sdk.modal.*;
import com.bxm.warcar.cache.DataExtractor;
import com.bxm.warcar.cache.Fetcher;
import com.bxm.warcar.utils.KeyBuilder;
import com.bxm.warcar.utils.TypeHelper;
import com.bxm.warcar.utils.http.pool.RestTemplatePool;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.util.UriComponents;
import org.springframework.web.util.UriComponentsBuilder;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;

/**
 * @author allen
 * @date 2021-06-08
 * @since 1.0
 */
@Slf4j
public class DefaultKylinApiClientImpl implements KylinApiClient {

    private final Fetcher fetcher;
    private final RestTemplatePool rest;
    private final KylinProperties kylinProperties;

    public DefaultKylinApiClientImpl(Fetcher fetcher, KylinProperties kylinProperties) {
        this.fetcher = fetcher;
        this.rest = new RestTemplatePool(kylinProperties);
        this.kylinProperties = kylinProperties;
    }

    @Override
    public List<Domain> getAvailableDomains(String groupId, String ua, String ip) {
        return this.getAvailableDomains(groupId, ua, ip, "");
    }

    @Override
    public List<Domain> getAvailableDomains(String groupId, String ua, String ip, String path) {
        Map<String, Object> params = Maps.newHashMap();
        params.put("groupId", groupId);
        params.put("ua", ua);
        params.put("ip", ip);
        params.put("path", path);
        try {
            String url = kylinProperties.getRedirectHost() + "/domains?groupId={groupId}&ua={ua}&ip={ip}&path={path}";
            HttpEntity<String> exchange = this.post(url, String.class, params);
            if (!exchange.hasBody()) {
                return null;
            }
            return JSONObject.parseArray(exchange.getBody(), Domain.class);
        } catch (Exception e) {
            log.error("post: ", e);
            return null;
        }
    }

    @Override
    public List<DomainGroup> getDomainGroups() {
        return fetcher.fetchList(() -> KeyBuilder.build("tmp", "kylin", "domainGroups"), new DataExtractor<List<DomainGroup>>() {
            @Override
            public List<DomainGroup> extract() {
                Map<String, Object> params = Maps.newHashMap();
                params.put("size", 100);
                params.put("current", 1);
                try {
                    String url = kylinProperties.getApiHost() + "/domain-group/page-query?size={size}&current={current}";
                    HttpEntity<DomainGroupPage> entity = get(url, DomainGroupPage.class, params);
                    DomainGroupPage body = entity.getBody();
                    if (Objects.isNull(body)) {
                        return null;
                    }
                    return body.getRecords();
                } catch (Exception e) {
                    log.error("exchange: ", e);
                    return null;
                }
            }
        }, DomainGroup.class, 5 * 60);
    }

    @Override
    public CheckPlan createCheckPlan(CreateCheckPlanParam param) {
        Long envId = param.getEnvId();
        Long groupId = param.getGroupId();
        Long domainId = param.getDomainId();
        String sourceUrl = param.getSourceUrl();
        String remark = param.getRemark();
        String webhook = param.getWebhook();
        return createCheckPlan0(envId, groupId, domainId, sourceUrl, remark, webhook);
    }

    private CheckPlan createCheckPlan0(Long envId, Long groupId, Long domainId, String sourceUrl, String remark, String webhook) {
        UriComponents build = UriComponentsBuilder.fromUriString(sourceUrl).build();

        String path = build.getPath();

        if (Objects.nonNull(groupId)) {
            CheckPlan exists = getCheckPlanOnCreateJustNow(envId, groupId, domainId, path);
            if (Objects.nonNull(exists)) {
                return exists;
            }
        }

        CheckPlan checkPlan = CheckPlan.builder()
                .environmentId(envId)
                .domainId(domainId)
                .checkPath(path)
                .expectStatusCode(200)
                .cronExpression("0 0/1 * * * ?")
                .status(1)
                .webhook(webhook)
                .remark(remark)
                .build();

        try {
            String url = kylinProperties.getApiHost() + "/check-plan/put";
            HttpEntity<CheckPlan> exchange = this.put(url, CheckPlan.class, checkPlan, Maps.newHashMap());
            CheckPlan res = exchange.getBody();
            if (Objects.nonNull(res)) {
                res.setLastCheckResult(CheckPlan.ENABLE);
            }
            return res;
        } catch (Exception e) {
            log.error("exchange: ", e);
            return null;
        }
    }

    @Override
    public void deleteCheckPlan(Long checkPlanId) {
        try {
            String url = kylinProperties.getApiHost() + "/check-plan/delete/" + checkPlanId;
            this.delete(url, String.class, Maps.newHashMap());
        } catch (Exception e) {
            log.info("{} delete checkPlan occur error: {}", checkPlanId, e.getMessage());
        }
    }

    @Override
    public boolean isAvailableDomain(Long domainId) {
        try {
            String url = kylinProperties.getApiHost() + "/domain/get/" + domainId;
            HttpEntity<DomainRo> httpEntity = this.get(url, DomainRo.class, Maps.newHashMap());
            DomainRo domainRo = httpEntity.getBody();
            return domainRo != null && domainRo.isAvailable();
        } catch (Exception e) {
            log.error("get domain: ", e);
            return true;
        }
    }

    /**
     * 获取指定条件下刚刚创建，还没有检测过的计划。
     *
     * @param envId EnvId
     * @param groupId Group id
     * @param domainId Domain id
     * @param path Path
     * @return 返回 null 则表示没有或有已检测过的计划
     */
    private CheckPlan getCheckPlanOnCreateJustNow(Long envId, Long groupId, Long domainId, String path) {
        Map<String, Object> params = Maps.newHashMap();
        params.put("size", 100);
        params.put("current", 1);
        params.put("environmentId", envId);
        params.put("groupId", groupId);
        params.put("domainId", domainId);
        params.put("status", "1");
        try {
            String url = kylinProperties.getApiHost() + "/check-plan/page-query?size={size}&current={current}&environmentId={environmentId}&groupId={groupId}&domainId={domainId}&status={status}";
            HttpEntity<CheckPlanPage> entity = get(url, CheckPlanPage.class, params);
            CheckPlanPage body = entity.getBody();
            if (Objects.isNull(body)) {
                return null;
            }
            List<CheckPlan> records = body.getRecords();
            Optional<CheckPlan> exists = records.stream().filter((e) -> e.isNewPlan() && StringUtils.equalsIgnoreCase(e.getCheckPath(), path)).findFirst();
            return exists.orElse(null);
        } catch (Exception e) {
            log.error("exchange: ", e);
            return null;
        }
    }

    private <T> HttpEntity<T> get(String url, Class<T> responseType, Map<String, Object> params) {
        HttpEntity<String> httpEntity = new HttpEntity<>(null, createHeaders());
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.GET, httpEntity, responseType, params);
    }

    private <T> HttpEntity<T> post(String url, Class<T> responseType, Map<String, Object> params) {
        HttpEntity<String> httpEntity = new HttpEntity<>(null, createHeaders());
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.POST, httpEntity, responseType, params);
    }

    private <T> HttpEntity<T> put(String url, Class<T> responseType, Object body, Map<String, Object> params) {
        HttpHeaders httpHeaders = createHeaders();
        httpHeaders.add("Content-Type", "application/json");
        HttpEntity<Object> httpEntity = new HttpEntity<>(body, httpHeaders);
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.PUT, httpEntity, responseType, params);
    }

    private <T> HttpEntity<T> delete(String url, Class<T> responseType, Map<String, Object> params) {
        HttpEntity<String> httpEntity = new HttpEntity<>(null, createHeaders());
        RestTemplate restTemplate = rest.builder();
        return restTemplate.exchange(url, HttpMethod.DELETE, httpEntity, responseType, params);
    }

    private HttpHeaders createHeaders() {
        HttpHeaders headers = new HttpHeaders();
        headers.add("x-kylin-super-sdk", TypeHelper.castToString(System.currentTimeMillis()));
        return headers;
    }
}
